==> core-0.9.1.1-dev-sources.jar: android/databinding/DataBinderMapperProxy.java <==
package android.databinding;

import android.support.annotation.NonNull;
import android.view.View;

import com.didi.virtualapk.PluginManager;
import com.didi.virtualapk.internal.LoadedPlugin;

import java.util.LinkedList;

/**
 * Created by qiaopu on 2018/4/11.
 */
public class DataBinderMapperProxy extends DataBinderMapper implements PluginManager.Callback {
    
    private final LinkedList<DataBinderMapper> mMappers;
    private DataBinderMapper[] mCache;
    
    public DataBinderMapperProxy(@NonNull Object source) {
        mMappers = new LinkedList<>();
    
        addMapper((DataBinderMapper) source);
    }
    
    @Override
    public ViewDataBinding getDataBinder(DataBindingComponent bindingComponent, View view, int layoutId) {
        ViewDataBinding viewDataBinding;
    
        for (DataBinderMapper mapper : getCache()) {
            viewDataBinding = mapper.getDataBinder(bindingComponent, view, layoutId);
            if (viewDataBinding != null) {
                return viewDataBinding;
            }
        }
        
        return null;
    }
    
    @Override
    ViewDataBinding getDataBinder(DataBindingComponent bindingComponent, View[] view, int layoutId) {
        ViewDataBinding viewDataBinding;
    
        for (DataBinderMapper mapper : getCache()) {
            viewDataBinding = mapper.getDataBinder(bindingComponent, view, layoutId);
            if (viewDataBinding != null) {
                return viewDataBinding;
            }
        }
    
        return null;
    }
    
    @Override
    public int getLayoutId(String tag) {
        int layoutId;
    
        for (DataBinderMapper mapper : getCache()) {
            layoutId = mapper.getLayoutId(tag);
            if (layoutId != 0) {
                return layoutId;
            }
        }
    
        return 0;
    }
    
    @Override
    public String convertBrIdToString(int id) {
        String brId;
    
        for (DataBinderMapper mapper : getCache()) {
            brId = mapper.convertBrIdToString(id);
            if (brId != null) {
                return brId;
            }
        }
    
        return null;
    }
    
    @Override
    public void onAddedLoadedPlugin(LoadedPlugin plugin) {
        try {
            String clsName = "android.databinding.DataBinderMapper_" + plugin.getPackageName().replace('.', '_');
            Class cls = Class.forName(clsName, true, plugin.getClassLoader());
            Object obj = cls.newInstance();
    
            addMapper((DataBinderMapper) obj);
            
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void addMapper(DataBinderMapper mapper) {
        synchronized (mMappers) {
            mMappers.add(mapper);
            mCache = null;
        }
    }
    
    private DataBinderMapper[] getCache() {
        synchronized (mMappers) {
            if (mCache == null) {
                mCache = mMappers.toArray(new DataBinderMapper[mMappers.size()]);
            }
            return mCache;
        }
    }
}

==> core-0.9.1.3-dev-sources.jar: android/databinding/DataBinderMapperProxy.java <==
package android.databinding;

import android.support.annotation.NonNull;
import android.util.Log;
import android.view.View;

import com.didi.virtualapk.PluginManager;
import com.didi.virtualapk.internal.LoadedPlugin;

import java.util.LinkedList;

/**
 * Created by qiaopu on 2018/4/11.
 */
public class DataBinderMapperProxy extends DataBinderMapper implements PluginManager.Callback {
    public static final String TAG = "DataBinderMapperProxy";
    
    private final LinkedList<DataBinderMapper> mMappers;
    private DataBinderMapper[] mCache;
    
    public DataBinderMapperProxy(@NonNull Object source) {
        mMappers = new LinkedList<>();
    
        addMapper((DataBinderMapper) source);
    }
    
    @Override
    public ViewDataBinding getDataBinder(DataBindingComponent bindingComponent, View view, int layoutId) {
        ViewDataBinding viewDataBinding;
    
        for (DataBinderMapper mapper : getCache()) {
            viewDataBinding = mapper.getDataBinder(bindingComponent, view, layoutId);
            if (viewDataBinding != null) {
                Log.i(TAG, "Found by mapper: " + mapper);
                return viewDataBinding;
            }
        }
        
        return null;
    }
    
    @Override
    ViewDataBinding getDataBinder(DataBindingComponent bindingComponent, View[] view, int layoutId) {
        ViewDataBinding viewDataBinding;
    
        for (DataBinderMapper mapper : getCache()) {
            viewDataBinding = mapper.getDataBinder(bindingComponent, view, layoutId);
            if (viewDataBinding != null) {
                Log.i(TAG, "Found by mapper: " + mapper);
                return viewDataBinding;
            }
        }
    
        return null;
    }
    
    @Override
    public int getLayoutId(String tag) {
        int layoutId;
    
        for (DataBinderMapper mapper : getCache()) {
            layoutId = mapper.getLayoutId(tag);
            if (layoutId != 0) {
                Log.i(TAG, "Found by mapper: " + mapper);
                return layoutId;
            }
        }
    
        return 0;
    }
    
    @Override
    public String convertBrIdToString(int id) {
        String brId;
    
        for (DataBinderMapper mapper : getCache()) {
            brId = mapper.convertBrIdToString(id);
            if (brId != null) {
                Log.i(TAG, "Found by mapper: " + mapper);
                return brId;
            }
        }
    
        return null;
    }
    
    @Override
    public void onAddedLoadedPlugin(LoadedPlugin plugin) {
        try {
            String clsName = "android.databinding.DataBinderMapper_" + plugin.getPackageName().replace('.', '_');
            Log.i(TAG, "Try to find the class: " + clsName);
            Class cls = Class.forName(clsName, true, plugin.getClassLoader());
            Object obj = cls.newInstance();
    
            addMapper((DataBinderMapper) obj);
            
        } catch (Exception e) {
            Log.w(TAG, e);
        }
    }
    
    private void addMapper(DataBinderMapper mapper) {
        synchronized (mMappers) {
            mMappers.add(mapper);
            mCache = null;
        }
    
        Log.i(TAG, "Added mapper: " + mapper);
    }
    
    private DataBinderMapper[] getCache() {
        synchronized (mMappers) {
            if (mCache == null) {
                mCache = mMappers.toArray(new DataBinderMapper[mMappers.size()]);
            }
            return mCache;
        }
    }
}
